@@ -204,7 +204,7 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
     
     # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
     if ('psycopg2' in DB_BACKEND and (
-            ((dsabbr.upper() in ['CORE', 'BASE', 'CHGS']) or
+            ((dsabbr.upper() in ['CORE', 'BASE', 'CHGS', 'DTE']) or
                 (dsabbr.upper() in ['CHGS'] and meta_is_long(load.get_meta()))
                 )
             )
@@ -261,10 +261,12 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
         # TODO: Expand for non-SID nomenclature
     elif dsabbr == 'CHGS':
         stcat = 'SID_CHARGES_SOURCE'
+    elif dsabbr == 'DTE':
+        stcat = 'DAYSTOEVENT_SOURCE'
     else:
         raise Exception("wtf are you doing? you know this code is all borked right now.")
     
-    stg_table_name = '_'.join(str(x) for x in [state, year, 'stg', stcat])
+    stg_table_name = '_'.join(str(x) for x in ['stg', state, year, stcat])
     handle = load.file.open()
 
     # establish connection directly with psycopg2
@@ -278,14 +280,34 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
         )
     
     # get helper functions
-    from pyhcup.db import pg_rawload, pg_staging, pg_shovel, pg_wtl_shovel, pg_drop
+    from pyhcup.db import pg_rawload, pg_staging, pg_shovel, pg_wtl_shovel, pg_drop, pg_dteload
     
     
     # segregate the csv loads from the non-csv loads
     if str(load.file.filename).split('.')[-1] == 'csv':
-        # just do a csv load, and assume a header is present
+        # just do a csv load
         
-        affected_rows = 0
+        # but only for daystoevent CSV files
+        if not stcat == 'DAYSTOEVENT_SOURCE':
+            raise Exception("At present, only stating table category DAYSTOEVENT_SOURCE is eligible for CSV loading.")
+        
+        load.log('Importing CSV file with DaysToEvent data',
+                level='INFO', logger=logger)
+        
+        result = pg_dteload(cnxn, handle, stg_table_name)
+        affected_rows = result[1]
+        
+        # save info about this import in a StagingTable object
+        imported = StagingTable(
+            imported_via = load,
+            name = stg_table_name,
+            category = stcat,
+            records = affected_rows
+        )
+        
+        imported.save()
+        
+        load.log('StagingTable %s recorded for %s' % (stg_table_name, imported.pk))
         
     else:
         # use the old style code
