@@ -138,7 +138,7 @@ def source_detail(request, source_id):
     files = File.objects.filter(file_type__source=source)
     file_types = FileType.objects.filter(source=source)
     
-    import_tables = ImportTable.objects.filter(source=source)
+    import_tables = StagingTable.objects.filter(imported_via__file__file_type__source=source)
     
     context = {
         'object_type': type(source),
@@ -407,9 +407,9 @@ def src_gen_master_table(request, source_id):
         except:
             raise Exception("Failed to create indexes on table, particularly one that should have resulted from this query: %s" % index)
     
-    table_record = ImportTable(source=source, name=db_table, database=DJHCUP_DB_ENTRY)
+    table_record = StagingTable(source=source, name=db_table, database=DJHCUP_DB_ENTRY)
     table_record.save()
-    logger.info('Saved master table details as ImportTable record %d' % table_record.pk)
+    logger.info('Saved master table details as StagingTable record %d' % table_record.pk)
     
     context = {
         'title': 'Generate Master Table',
